@@ -29,7 +29,7 @@ def getAccountUsers(token, hubId):
     usuarios = []
     
     for user in response.json():
-        usuario = CLASSES.User(user['id'], user['email'], user['name'], "NA", "NA")
+        usuario = CLASSES.User(user['id'], user['email'], user['name'], "NA", "NA", "NA")
         usuarios.append(usuario)
     
     return usuarios
@@ -49,7 +49,8 @@ def getProjectUsers(token, pjtId, offset):
     usuarios = []
     
     for user in response.json()['results']:
-        usuario = CLASSES.User(user['id'], user['email'],user['name'], user['jobTitle'], user['roleIds'])
+        usuario = CLASSES.User(user['id'], user['email'],user['name'], user['jobTitle'], user['roleIds'], user['companyId'])
+        usuario.autodeskId = user['autodeskId']
         usuarios.append(usuario)
         
     return [[response.json()['pagination']['limit'], response.json()['pagination']['offset'], response.json()['pagination']['totalResults']], usuarios]
@@ -183,4 +184,23 @@ def getProjectIssues(token, container):
 
         issues.append(issue_obj)
     
-    return issues
\ No newline at end of file
+    return issues
+
+def GetCompanies(token, hubId):
+    url = "https://developer.api.autodesk.com/hq/v1/accounts/{0}/companies".format(hubId)
+
+    querystring = {"limit":"100"}
+
+    headers = {
+    'authorization': "Bearer "+token
+    }
+
+    response = requests.request("GET", url, headers=headers, params=querystring)
+
+    empresas = []
+
+    for company in response.json():
+        empresa = CLASSES.Company(company['id'], company['name'], company['city'], company['state_or_province'], company['country'])
+        empresas.append(empresa)
+    
+    return empresas
\ No newline at end of file
